package org.jeecg.api.controller;


import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.api.bean.PageBean;
import org.jeecg.api.service.AppletIndexService;
import org.jeecg.common.api.vo.Result;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;

/**
 * 集中所有登录接口
 */

@Api(tags="珠宝项目-首页接口")
@RestController
@RequestMapping("/index_common")
@Slf4j
public class AppletIndexController {



    @Resource
    private AppletIndexService apiRiceService;


    //获取首页轮播图
    @ApiOperation(value="获取首页轮播图", notes="获取首页轮播图")
    @GetMapping(value = "/getRiceBanner")
    public Result<?> getRiceBanner() {
        return apiRiceService.getRiceBanner();
    }

    //获取首页公告列表
    @ApiOperation(value="获取首页公告列表", notes="获取首页公告列表")
    @GetMapping(value = "/getRiceNoticeList")
    public Result<?> getRiceNoticeList() {
        return apiRiceService.getRiceNoticeList();
    }





    //获取会员信息
    @ApiOperation(value="获取会员信息", notes="获取会员信息")
    @GetMapping(value = "/getVipInfoList")
    public Result<?> getVipInfoList(){
        return apiRiceService.getVipInfoList();
    }









    //获取首页跳转图标
    @ApiOperation(value="获取首页跳转图标", notes="获取首页跳转图标")
    @GetMapping(value = "/getRiceIconList")
    public Result<?> getRiceIconList() {
        return apiRiceService.getRiceIconList();
    }




    //获取首页广告列表
    @ApiOperation(value="获取首页广告列表", notes="获取首页广告列表")
    @GetMapping(value = "/getRiceAdList")
    public Result<?> getRiceAdList(PageBean pageBean) {
        return apiRiceService.getRiceAdList(pageBean);
    }






    //获取分类分页商品列表接口
    @ApiOperation(value="获取分类分页商品列表接口", notes="获取分类分页商品列表接口")
    @GetMapping(value = "/getClassShopPageList")
    public Result<?> getClassShopPageList(PageBean pageBean, String classId) {
        return apiRiceService.getClassShopPageList(pageBean,classId);
    }



    //获取首页商品详情
    @ApiOperation(value="获取首页商品详情", notes="获取首页商品详情")
    @GetMapping(value = "/getRiceProductDetail")
    public Result<?> getRiceProductDetail(String id) {
        return apiRiceService.getRiceProductDetail(id);
    }

    //获取首页新闻列表
    @ApiOperation(value="获取首页新闻列表", notes="获取首页新闻列表")
    @GetMapping(value = "/getRiceNewsList")
    public Result<?> getRiceNewsList() {
        return apiRiceService.getRiceNewsList();
    }

















    //加入购物车 传入token shopId num
    @ApiOperation(value="加入购物车 传入token shopId num", notes="加入购物车 传入token shopId num")
    @GetMapping(value = "/addCart")
    public Result<?> addCart(@RequestHeader("X-Access-Token") String token, String shopId, Integer num){
        return apiRiceService.addCart(token,shopId,num);
    }


    //删除购物车信息
    @ApiOperation(value="删除购物车信息", notes="删除购物车信息")
    @DeleteMapping(value = "/deleteCart")
    public Result<?> deleteCart(@RequestHeader("X-Access-Token") String token,String ids){
        return apiRiceService.deleteCart(token,ids);
    }


    //修改购物车信息数量
    @ApiOperation(value="修改购物车信息数量", notes="修改购物车信息数量")
    @PostMapping(value = "/updateCartNum")
    public Result<?> updateCartNum(@RequestHeader("X-Access-Token") String token,String id,Integer num){
        return apiRiceService.updateCartNum(token,id,num);
    }



    //查询分类接口
    @ApiOperation(value="查询分类接口", notes="查询分类接口")
    @GetMapping(value = "/getCategoryList")
    private Result<?> getCategoryList(){
        return apiRiceService.getCategoryList();
    }








    //创建订单
    @ApiOperation(value="创建订单", notes="创建订单")
    @GetMapping(value = "/createOrder")
    public Result<?> createOrder(@RequestHeader("X-Access-Token") String token, String shopId, Integer num,String addressId) {
        return apiRiceService.createOrder(token,shopId,num,addressId);
    }


    //创建订单
    @ApiOperation(value="创建订单-再次支付", notes="创建订单-再次支付")
    @GetMapping(value = "/createOrderTwo")
    public Result<?> createOrderTwo(@RequestHeader("X-Access-Token") String token,String orderId) {
        return apiRiceService.createOrderTwo(token,orderId);
    }


    //商城-加入购物车之后一次下多个订单
    @ApiOperation(value="商城-加入购物车之后一次下多个订单", notes="商城-加入购物车之后一次下多个订单")
    @PostMapping("/createSumOrder")
    public Result<?> createSumOrder(@RequestHeader("X-Access-Token") String token,String list,String addressId){
        return apiRiceService.createSumOrder(token,list,addressId);
    }



    //商城-加入购物车之后一次下多个订单 - 再次下单
    @ApiOperation(value="商城-加入购物车之后一次下多个订单 - 再次下单", notes="商城-加入购物车之后一次下多个订单 - 再次下单")
    @PostMapping("/createSumOrderAgain")
    public Result<?> createSumOrderAgain(@RequestHeader("X-Access-Token") String token,String orderId){
        return apiRiceService.createSumOrderAgain(token,orderId);
    }





    @PostMapping("/payNotify")
    public Object payNotify(@RequestBody String requestBody){
        return apiRiceService.payNotify(requestBody);
    }



    //确认收货
    @ApiOperation(value="确认收货", notes="确认收货")
    @GetMapping(value = "/confirmOrder")
    public Result<?> confirmOrder(@RequestHeader("X-Access-Token") String token,String orderId) {
        return apiRiceService.confirmOrder(token,orderId);
    }





}
