package org.jeecg.api.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.api.bean.PageBean;
import org.jeecg.api.service.AppletIndexService;
import org.jeecg.common.api.vo.Result;
import org.jeecg.modules.commonAddress.entity.CommonAddress;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.math.BigDecimal;

@Api(tags="珠宝项目-个人中心接口")
@RestController
@RequestMapping("/info_common")
@Slf4j
public class AppletInfoController {


    @Resource
    private AppletIndexService apiRiceService;

    //获取优惠券信息
    @ApiOperation(value="获取优惠券信息", notes="获取优惠券信息")
    @GetMapping(value = "/getRiceCouponList")
    public Result<?> getRiceCouponList(@RequestHeader("X-Access-Token") String token,PageBean pageBean) {
        return apiRiceService.getRiceCouponList(token,pageBean);
    }


    //获取流水记录带分页
    @ApiOperation(value="获取流水记录带分页", notes="获取流水记录带分页")
    @GetMapping(value = "/getWaterPageList")
    public Result<?> getWaterPageList(@RequestHeader("X-Access-Token") String token, PageBean pageBean){
        return apiRiceService.getWaterPageList(token,pageBean);
    }

    //获取订单列表带分页
    @ApiOperation(value="获取订单列表带分页", notes="获取订单列表带分页")
    @GetMapping(value = "/getOrderPageList")
    public Result<?> getOrderPageList(@RequestHeader("X-Access-Token") String token, PageBean pageBean,Integer state){
        return apiRiceService.getOrderPageList(token,pageBean,state);
    }



    //获取订单详情
    @ApiOperation(value="获取订单详情", notes="获取订单详情")
    @GetMapping(value = "/getOrderDetail")
    public Result<?> getOrderDetail(@RequestHeader("X-Access-Token") String token,String id){
        return apiRiceService.getOrderDetail(token,id);
    }








    //获取地址列表带分页
    @ApiOperation(value="获取地址列表带分页", notes="获取地址列表带分页")
    @GetMapping(value = "/getAddressPageList")
    public Result<?> getAddressPageList(@RequestHeader("X-Access-Token") String token,PageBean pageBean){
        return apiRiceService.getAddressPageList(token,pageBean);
    }

    //获取粉丝列表带分页
    @ApiOperation(value="获取粉丝列表带分页", notes="获取粉丝列表带分页")
    @GetMapping(value = "/getFansPageList")
    public Result<?> getFansPageList(@RequestHeader("X-Access-Token") String token,PageBean pageBean,String title){
        return apiRiceService.getFansPageList(token,pageBean,title);
    }

    //获取个人邀请码
    @ApiOperation(value="获取个人邀请码", notes="获取个人邀请码")
    @GetMapping(value = "/getInviteCode")
    public Result<?> getInviteCode(@RequestHeader("X-Access-Token") String token){
        return apiRiceService.getInviteCode(token);
    }

    //获取购物车信息列表带分页
    @ApiOperation(value="获取购物车信息列表带分页", notes="获取购物车信息列表带分页")
    @GetMapping(value = "/getCartPageList")
    public Result<?> getCartPageList(@RequestHeader("X-Access-Token") String token,PageBean pageBean){
        return apiRiceService.getCartPageList(token,pageBean);
    }


    //获取相关介绍
    @ApiOperation(value="获取相关介绍", notes="获取相关介绍")
    @GetMapping(value = "/getInfoIntroduce")
    public Result<?> getInfoIntroduce(String type){
        return apiRiceService.getInfoIntroduce(type);
    }



    //增加或修改地址信息
    @ApiOperation(value="增加或修改地址信息", notes="增加或修改地址信息")
    @PostMapping(value = "/addOrUpdateAddress")
    public Result<?> addOrUpdateAddress(@RequestHeader("X-Access-Token") String token, CommonAddress commonAddress){
        return apiRiceService.addOrUpdateAddress(token,commonAddress);
    }



    //删除地址
    @ApiOperation(value="删除地址", notes="删除地址")
    @GetMapping(value = "/deleteAddress")
    public Result<?> deleteAddress(@RequestHeader("X-Access-Token") String token,String id){
        return apiRiceService.deleteAddress(token,id);
    }


    //修改默认地址
    @ApiOperation(value="修改默认地址", notes="修改默认地址")
    @GetMapping(value = "/updateDefaultAddress")
    public Result<?> updateDefaultAddress(@RequestHeader("X-Access-Token") String token,String id){
        return apiRiceService.updateDefaultAddress(token,id);
    }



    //查询个人信息相关
    @ApiOperation(value="查询个人信息相关", notes="查询个人信息相关")
    @GetMapping(value = "/getRiceInfo")
    public Result<?> getRiceInfo(String token){
        return apiRiceService.getRiceInfo(token);
    }



    //充值
    @ApiOperation(value="充值", notes="充值")
    @GetMapping(value = "/recharge")
    public Result<?> recharge(@RequestHeader("X-Access-Token") String token, BigDecimal money){
        return apiRiceService.recharge(token,money);
    }





    //提现
    @ApiOperation(value="提现", notes="提现")
    @GetMapping(value = "/withdraw")
    public Result<?> withdraw(@RequestHeader("X-Access-Token") String token,BigDecimal money,String bankName,String bankNo){
        return apiRiceService.withdraw(token,money,bankName,bankNo);
    }



}
