package org.jeecg.api.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.TypeReference;
import com.aliyun.oss.OSS;
import com.aliyun.oss.OSSClientBuilder;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.binarywang.wxpay.bean.notify.WxPayOrderNotifyResult;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.apache.commons.fileupload.FileItem;
import org.apache.commons.fileupload.disk.DiskFileItemFactory;
import org.jeecg.api.bean.HttpClientUtil;
import org.jeecg.api.bean.PageBean;
import org.jeecg.api.bean.WxQrCodeVo;
import org.jeecg.api.service.AppletIndexService;
import org.jeecg.common.api.vo.Result;
import org.jeecg.config.shiro.ShiroRealm;
import org.jeecg.modules.commonAddress.entity.CommonAddress;
import org.jeecg.modules.commonAddress.service.ICommonAddressService;
import org.jeecg.modules.commonBanner.entity.CommonBanner;
import org.jeecg.modules.commonBanner.service.ICommonBannerService;
import org.jeecg.modules.commonCat.entity.CommonCat;
import org.jeecg.modules.commonCat.service.ICommonCatService;
import org.jeecg.modules.commonClass.entity.CommonClass;
import org.jeecg.modules.commonClass.service.ICommonClassService;
import org.jeecg.modules.commonConfig.entity.CommonConfig;
import org.jeecg.modules.commonConfig.service.ICommonConfigService;
import org.jeecg.modules.commonCoupon.entity.CommonCoupon;
import org.jeecg.modules.commonCoupon.service.ICommonCouponService;
import org.jeecg.modules.commonIcon.entity.CommonIcon;
import org.jeecg.modules.commonIcon.service.ICommonIconService;
import org.jeecg.modules.commonIconImage.entity.CommonIconImage;
import org.jeecg.modules.commonIconImage.service.ICommonIconImageService;
import org.jeecg.modules.commonMoney.entity.CommonMoney;
import org.jeecg.modules.commonMoney.service.ICommonMoneyService;
import org.jeecg.modules.commonMoneyLog.entity.CommonMoneyLog;
import org.jeecg.modules.commonMoneyLog.service.ICommonMoneyLogService;
import org.jeecg.modules.commonNews.entity.CommonNews;
import org.jeecg.modules.commonNews.service.ICommonNewsService;
import org.jeecg.modules.commonNotice.entity.CommonNotice;
import org.jeecg.modules.commonNotice.service.ICommonNoticeService;
import org.jeecg.modules.commonOrder.entity.CommonOrder;
import org.jeecg.modules.commonOrder.service.ICommonOrderService;
import org.jeecg.modules.commonOrderSku.entity.CommonOrderSku;
import org.jeecg.modules.commonOrderSku.service.ICommonOrderSkuService;
import org.jeecg.modules.commonShop.entity.CommonShop;
import org.jeecg.modules.commonShop.service.ICommonShopService;
import org.jeecg.modules.commonVip.entity.CommonVip;
import org.jeecg.modules.commonVip.service.ICommonVipService;
import org.jeecg.modules.commonVipConfig.entity.CommonVipConfig;
import org.jeecg.modules.commonVipConfig.service.ICommonVipConfigService;
import org.jeecg.modules.hanHaiMember.entity.HanHaiMember;
import org.jeecg.modules.hanHaiMember.service.IHanHaiMemberService;
import org.jeecg.modules.pay.MpWxPayService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpMethod;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.client.RestTemplate;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.commons.CommonsMultipartFile;

import javax.annotation.Resource;
import javax.transaction.Transactional;
import java.io.*;
import java.math.BigDecimal;
import java.util.*;

@Slf4j
@Service
public class AppletIndexServiceImpl implements AppletIndexService {


    @Resource
    private ICommonAddressService commonAddressService;
    @Resource
    private ICommonBannerService commonBannerService;
    @Resource
    private ICommonCatService commonCatService;
    @Resource
    private ICommonClassService commonClassService;
    @Resource
    private ICommonConfigService commonConfigService;
    @Resource
    private ICommonMoneyService commonMoneyService;
    @Resource
    private ICommonIconImageService commonIconImageService;
    @Resource
    private ICommonMoneyLogService commonMoneyLogService;
    @Resource
    private ICommonNewsService commonNewsService;
    @Resource
    private ICommonNoticeService commonNoticeService;
    @Resource
    private ICommonOrderService commonOrderService;
    @Resource
    private ICommonOrderSkuService commonOrderSkuService;
    @Resource
    private ICommonShopService commonShopService;

    @Resource
    private IHanHaiMemberService hanHaiMemberService;

    @Resource
    private ICommonVipConfigService commonVipConfigService;
    //权限配置
    @Resource
    private ShiroRealm shiroRealm;
    //支付接口
    @Autowired
    private MpWxPayService mpWxPayService;
    //首页广告
    @Resource
    private ICommonIconService commonIconService;
    @Resource
    private ICommonCouponService commonCouponService;

    @Resource
    private ICommonVipService commonVipService;







    //获取首页轮播图
    @Override
    public Result<?> getRiceBanner() {
        List<CommonBanner> list = commonBannerService.list();
        return Result.OK(list);
    }
    //获取首页公告列表
    @Override
    public Result<?> getRiceNoticeList(){
        CommonNotice commonNotice = commonNoticeService.list().get(0);
        return Result.OK(commonNotice);
    }



    //获取会员信息
    @Override
    public Result<?> getVipInfoList(){
        List<CommonVip> list = commonVipService.list();
        return Result.OK(list);
    }

    //获取首页跳转图标

    @Override
    public Result<?> getRiceIconList() {
        List<CommonIconImage> list = commonIconImageService
                .lambdaQuery()
                .orderByDesc(CommonIconImage::getSort)
                .list();
        return Result.OK(list);
    }


    //获取首页广告列表
    @Override
    public Result<?> getRiceAdList(PageBean pageBean){
        Page<CommonIcon> page = new Page<CommonIcon>(pageBean.getPageNo(), pageBean.getPageSize());
        Page<CommonIcon> page1 = commonIconService.page(page);
        return Result.OK(page1);
    }


    @Override
    public Result<?> getClassShopPageList(PageBean pageBean, String classId){
        Page<CommonShop> page = new Page<CommonShop>(pageBean.getPageNo(), pageBean.getPageSize());
        Page<CommonShop> page1 = commonShopService.page(page);
        //如果分类标识不为空
        if(classId!=null){
            IPage<CommonShop> pageList =
                    commonShopService.lambdaQuery()
                            .eq(CommonShop::getClassId,classId)
                            .eq(CommonShop::getType,2)
                            .orderByDesc(CommonShop::getCreateTime)
                            .page(page);
            return Result.OK(pageList);
        }
        return Result.OK(page1);
    }




    //获取优惠券信息列表
    @Override
    public Result<?> getRiceCouponList(String token, PageBean pageBean){
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);
        Page<CommonCoupon> page = new Page<CommonCoupon>(pageBean.getPageNo(), pageBean.getPageSize());
        Page<CommonCoupon> page1 = commonCouponService
                .lambdaQuery()
                .eq(CommonCoupon::getUserId,hanHaiMember.getId())
                .page(page);
        return Result.OK(hanHaiMember);
    }


    //获取首页商品详情
    @Override
    public Result<?> getRiceProductDetail(String id){
        CommonShop byId = commonShopService.getById(id);
        return Result.OK(byId);
    }

    //获取首页新闻列表

    @Override
    public Result<?> getRiceNewsList(){
        int pageNo = 1;
        int pageSize = 10;
        Page<CommonNews> page = new Page<CommonNews>(pageNo, pageSize);
        Page<CommonNews> page1 = commonNewsService.page(page);
        return Result.OK(page1);
    }



    //再次支付
    @Override
    @Transactional
    public Result<?> createOrderTwo(String token,String orderId){
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);
        //查询订单是否存在
        CommonOrder commonOrder = commonOrderService.getById(orderId);
        if (commonOrder==null){
            return Result.error("订单不存在");
        }
        if (commonOrder.getState()==1){
            return Result.error("订单已支付");
        }
        //查询订单是否shopState不等于2
        if (commonOrder.getShopState()==2){
            return Result.error("非首页订单");
        }

        //根据配置列表查询每人限制数量
        CommonConfig commonConfig = commonConfigService.lambdaQuery()
                .eq(CommonConfig::getKeyName,"pay_num")
                .one();
        //得到配置的数值转为int类型
        int payNum = Integer.parseInt(commonConfig.getKeyContent());
        //根据商品信息是否是体验装进行判断
        if (commonOrder.getShopState()==0){
            //查询用户是否存在该订单
            List<CommonOrder> byUserIdAndShopId = commonOrderService.lambdaQuery()
                    .eq(CommonOrder::getUserId,hanHaiMember.getId())
                    .eq(CommonOrder::getShopId,commonOrder.getShopId())
                    .eq(CommonOrder::getShopState,0)
                    .eq(CommonOrder::getState,1)
                    .list();
            if (byUserIdAndShopId.size()+1>payNum){
                Result result = new Result();
                result.setMessage("已超过体验商品购买次数限制！请勿重复购买");
                result.setCode(901);
                return result;
            }

            //查询用户是否存在该订单
            List<CommonOrder> payNumList = commonOrderService.lambdaQuery()
                    .eq(CommonOrder::getUserId,hanHaiMember.getId())
                    .eq(CommonOrder::getShopId,commonOrder.getShopId())
                    .eq(CommonOrder::getShopState,0)
                    .eq(CommonOrder::getState,0)
                    .list();
            if (payNumList.size()>1){
                Result result = new Result();
                result.setMessage("您有相同订单未付款！请先付款");
                result.setCode(901);
                return result;
            }
        }




        //创建订单标识
        String newOrderId = IdWorker.getIdStr();
        //老的订单数据复制给新创建的订单对象
        CommonOrder commonOrder1 = new CommonOrder();
        commonOrder1.setId(newOrderId);
        commonOrder1.setShopState(0);
        commonOrder1.setUserId(hanHaiMember.getId());
        commonOrder1.setTitle(commonOrder.getTitle());
        commonOrder1.setImage(commonOrder.getImage());
        commonOrder1.setPrice(commonOrder.getPrice());
        commonOrder1.setNum(commonOrder.getNum());
        commonOrder1.setShopId(commonOrder.getShopId());
        commonOrder1.setPayNo(commonOrder.getPayNo());
        commonOrder1.setAddressId(commonOrder.getAddressId());
        commonOrder1.setAddressDetails(commonOrder.getAddressDetails());
        commonOrder1.setAddress(commonOrder.getAddress());
        commonOrder1.setState(0);
        commonOrder1.setName(commonOrder.getName());
        commonOrder1.setPhone(commonOrder.getPhone());
        commonOrder1.setSku(commonOrder.getSku());
        commonOrder1.setCreateTime(new Date());
        commonOrderService.save(commonOrder1);









        //根据订单标识查询订单详情对象
        CommonOrderSku commonOrderSku = new CommonOrderSku();
        commonOrderSku.setOrderId(newOrderId);
        commonOrderSku.setUserId(hanHaiMember.getId());
        commonOrderSku.setTitle(commonOrder.getTitle());
        commonOrderSku.setImage(commonOrder.getImage());
        commonOrderSku.setPrice(commonOrder.getPrice());
        commonOrderSku.setNum(commonOrder.getNum());
        commonOrderSku.setShopId(commonOrder.getShopId());
        commonOrderSku.setSku(commonOrder.getSku());
        commonOrderSku.setCreateTime(new Date());
        commonOrderSkuService.save(commonOrderSku);

        //删除原订单
        commonOrderService.removeById(orderId);
        //查询订单关联的订单详情
        CommonOrderSku one = commonOrderSkuService.lambdaQuery().eq(CommonOrderSku::getOrderId, orderId)
                .one();
        //删除该订单详情
        commonOrderSkuService.removeById(one);



        //吊起微信支付
        String s = commonOrder1.getPrice().multiply(new BigDecimal(100)).toString();
        int i1 = Double.valueOf(s).intValue();
        Object appOrder = mpWxPayService.createOrder(
                "购买"+ commonOrder1.getTitle() ,
                "127.0.0.1",
                orderId,
                i1,
                orderId,
                hanHaiMember.getAppletOpenid(),
                commonOrder.toString());

        return Result.OK("支付成功",appOrder);
    }

    //创建订单
    @Override
    public Result<?> createOrder(String token,String shopId,Integer num,String addressId) {
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);
        //商品标识不能为空
        if (shopId==null){
            return Result.error("商品标识不能为空");
        }
        //数量不能为空
        if (num==null){
            return Result.error("数量不能为空");
        }
        //查询商品信息
        CommonShop commonShop = commonShopService.getById(shopId);
        //商品不能为空
        if (commonShop==null){
            return Result.error("商品不存在");
        }
        //地址标识不能为空
        if (addressId==null){
            return Result.error("地址标识不能为空");
        }
        //查询地址是否存在
        CommonAddress commonAddress = commonAddressService.getById(addressId);
        if (commonAddress==null){
            return Result.error("地址不存在");
        }


        //根据配置列表查询每人限制数量
        CommonConfig commonConfig = commonConfigService.lambdaQuery()
                .eq(CommonConfig::getKeyName,"pay_num")
                .one();
        //得到配置的数值转为int类型
        int payNum = Integer.parseInt(commonConfig.getKeyContent());
        //根据商品信息是否是体验装进行判断
        if (commonShop.getType()==0){
            //查询用户是否存在该订单
            List<CommonOrder> byUserIdAndShopId = commonOrderService.lambdaQuery()
                    .eq(CommonOrder::getUserId,hanHaiMember.getId())
                    .eq(CommonOrder::getShopId,shopId)
                    .eq(CommonOrder::getShopState,0)
                    .eq(CommonOrder::getState,1)
                    .list();
            if (byUserIdAndShopId.size()+1>payNum){
                Result result = new Result();
                result.setMessage("已超过体验商品购买次数限制！请勿重复购买");
                result.setCode(901);
                return result;
            }

            //查询用户是否存在该订单
            List<CommonOrder> payNumList = commonOrderService.lambdaQuery()
                    .eq(CommonOrder::getUserId,hanHaiMember.getId())
                    .eq(CommonOrder::getShopId,shopId)
                    .eq(CommonOrder::getShopState,0)
                    .eq(CommonOrder::getState,0)
                    .list();
            if (payNumList.size()>0){
                Result result = new Result();
                result.setMessage("已超过体验商品购买次数限制！请勿重复购买");
                result.setCode(901);
                return result;
            }
        }


        //创建订单标识
        String orderId = IdWorker.getIdStr();
        //创建订单
        BigDecimal price = commonShop.getPrice().multiply(new BigDecimal(num));

        //生成订单信息
        CommonOrder commonOrder = new CommonOrder();

        commonOrder.setId(orderId);
        commonOrder.setTitle(commonShop.getTitle());
        commonOrder.setShopId(commonShop.getId());
        commonOrder.setImage(commonShop.getImage());
        commonOrder.setState(0);
        commonOrder.setPrice(price);
        commonOrder.setNum(num);
        commonOrder.setSku(commonShop.getSku());
        commonOrder.setName(commonAddress.getName());
        commonOrder.setPhone(commonAddress.getPhone());
        commonOrder.setAddress(commonAddress.getAddress());
        commonOrder.setAddressDetails(commonAddress.getAddressDetails());

        commonOrder.setUserId(hanHaiMember.getId());
        commonOrder.setAddressId(addressId);
        commonOrder.setShopState(commonShop.getType());
        commonOrderService.save(commonOrder);

        //创建订单详情
        CommonOrderSku commonOrderSku = new CommonOrderSku();
        commonOrderSku.setOrderId(orderId);
        commonOrderSku.setShopId(commonShop.getId());
        commonOrderSku.setTitle(commonShop.getTitle());
        commonOrderSku.setImage(commonShop.getImage());
        commonOrderSku.setPrice(price);
        commonOrderSku.setNum(num);
        commonOrderSku.setSku(commonShop.getSku());
        commonOrderSku.setCreateTime(new Date());
        commonOrderSkuService.save(commonOrderSku);

        //吊起微信支付
        String s = price.multiply(new BigDecimal(100)).toString();
        int i1 = Double.valueOf(s).intValue();
        Object appOrder = mpWxPayService.createOrder(
                "购买"+ commonShop.getTitle() ,
                "127.0.0.1",
                orderId,
                i1,
                orderId,
                hanHaiMember.getAppletOpenid(),
                commonOrder.toString());

        return Result.OK("支付成功",appOrder);
    }


    //商城-立即购买多少商品
    @Override
    public Result<?> createSumOrder(String token,String list,String addressId){
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);
        //用户地址不能为空
        if(StringUtils.isBlank(addressId)){
            return Result.error("请选择收货地址");
        }
        //查询地址是否存在
        CommonAddress commonAddress = commonAddressService.getById(addressId);
        if (commonAddress==null){
            return Result.error("地址不存在");
        }
        //把list转为对象 list = [{"shopId":"1","num":1},{"shopId":"2","num":2}]
        List<CommonOrderSku> list1 = JSON.parseArray(list, CommonOrderSku.class);
        //创建订单标识
        String orderId = IdWorker.getIdStr();
        if(null!=list1 && list1.size()>0){
            //订单总额
            BigDecimal totalPrice = new BigDecimal(0);
            //订单商品数量
            Integer totalNum = 0;

            //创建订单详情
            for (CommonOrderSku sku : list1) {
                //查询商品信息
                CommonShop commonShop = commonShopService.getById(sku.getShopId());
                //商品不能为空
                if (commonShop==null){
                    return Result.error("商品不存在");
                }
                //创建订单
                BigDecimal price = commonShop.getPrice().multiply(new BigDecimal(sku.getNum()));


                //获取vip价格
                if(hanHaiMember.getIsPay() == 1){
                    price = commonShop.getVipPrice().multiply(new BigDecimal(sku.getNum()));
                }


                sku.setOrderId(orderId);
                sku.setShopId(commonShop.getId());
                sku.setTitle(commonShop.getTitle());
                sku.setImage(commonShop.getImage());
                sku.setPrice(price);
                sku.setNum(sku.getNum());
                sku.setSku(commonShop.getSku());
                sku.setCreateTime(new Date());
                sku.setPrice(price);

                sku.setImage(commonShop.getImage());
                sku.setCreateTime(new Date());
                sku.setOrderId(orderId);
                commonOrderSkuService.save(sku);

                //计算总价格
                totalPrice = totalPrice.add(price);

                totalNum = totalNum + sku.getNum();
            }


            //创建主订单
            CommonOrder cityOrder = new CommonOrder();
            cityOrder.setId(orderId);
            cityOrder.setUserId(hanHaiMember.getId());
            cityOrder.setShopId(null);
            cityOrder.setNum(totalNum);
            cityOrder.setAddress(commonAddress.getAddress());
            cityOrder.setName(commonAddress.getName());
            cityOrder.setPhone(commonAddress.getPhone());
            cityOrder.setAddressDetails(commonAddress.getAddressDetails());
            cityOrder.setAddressId(addressId);
            cityOrder.setName("店铺订单");
            cityOrder.setTitle("组合订单");
            cityOrder.setPrice(totalPrice);
            cityOrder.setShopState(2);

            cityOrder.setImage(null);
            cityOrder.setState(0);
            cityOrder.setCreateTime(new Date());

            commonOrderService.save(cityOrder);

            //吊起微信支付
            String s = totalPrice.multiply(new BigDecimal(100)).toString();
            int i1 = Double.valueOf(s).intValue();
            Object appOrder = mpWxPayService.createOrder(
                    "购买"+ "组合订单" ,
                    "127.0.0.1",
                    orderId,
                    i1,
                    orderId,
                    hanHaiMember.getAppletOpenid(),
                    cityOrder.toString());

            return Result.OK("支付成功",appOrder);
        }
        return null;
    }



    //商城-加入购物车之后一次下多个订单 - 再次下单
    @Override
    public Result<?> createSumOrderAgain(String token,String order){
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);
        //根据订单标识查询订单是否存在
        CommonOrder oldOrder = commonOrderService.getById(order);
        if (oldOrder==null){
            return Result.error("订单不存在");
        }
        //储存地址标识
        String addressId = oldOrder.getAddressId();
        //创建订单标识
        String orderId = IdWorker.getIdStr();

        //根据订单标识查询订单详情列表
        List<CommonOrderSku> commonOrderSkuList = commonOrderSkuService.lambdaQuery()
                .eq(CommonOrderSku::getOrderId,order)
                .list();
        if (commonOrderSkuList==null || commonOrderSkuList.size()==0){
            return Result.error("订单详情不存在");
        }
        //循环修改订单标识
        for (CommonOrderSku commonOrderSku : commonOrderSkuList) {
            commonOrderSku.setOrderId(orderId);
            commonOrderSkuService.updateById(commonOrderSku);
        }



        //用户地址不能为空
        if(StringUtils.isBlank(addressId)){
            return Result.error("请选择收货地址");
        }
        //查询地址是否存在
        CommonAddress commonAddress = commonAddressService.getById(addressId);
        if (commonAddress==null){
            return Result.error("地址不存在");
        }

        //创建主订单
        CommonOrder cityOrder = new CommonOrder();
        cityOrder.setId(orderId);
        cityOrder.setUserId(oldOrder.getUserId());
        cityOrder.setShopId(null);
        cityOrder.setNum(oldOrder.getNum());
        cityOrder.setAddress(oldOrder.getAddress());
        cityOrder.setName(oldOrder.getName());
        cityOrder.setPhone(oldOrder.getPhone());
        cityOrder.setAddressDetails(oldOrder.getAddressDetails());
        cityOrder.setAddressId(addressId);
        cityOrder.setName("店铺订单");
        cityOrder.setTitle("组合订单");

        cityOrder.setPrice(oldOrder.getPrice());

        cityOrder.setImage(null);
        cityOrder.setState(0);
        cityOrder.setShopState(2);
        cityOrder.setCreateTime(new Date());

        commonOrderService.save(cityOrder);

        //删除旧订单
        commonOrderService.removeById(order);

        //吊起微信支付
        String s = oldOrder.getPrice().multiply(new BigDecimal(100)).toString();
        int i1 = Double.valueOf(s).intValue();
        Object appOrder = mpWxPayService.createOrder(
                "购买"+ "组合订单" ,
                "127.0.0.1",
                orderId,
                i1,
                orderId,
                hanHaiMember.getAppletOpenid(),
                cityOrder.toString());

        return Result.OK("支付成功",appOrder);

    }


    //商城-支付回调
    @Override
    public Result<?> payNotify(String requestBody){
        WxPayOrderNotifyResult notify = mpWxPayService.notify(requestBody);
        String outTradeNo = notify.getOutTradeNo();
        log.info("支付回调订单号码："+outTradeNo);
        //查询订单信息
        CommonOrder commonOrder = commonOrderService.getById(outTradeNo);
        //如果订单存在则修改订单状态
        if (commonOrder!=null){
            if(commonOrder.getState()==0){
                //修改订单状态
                if(commonOrder.getShopState()==0){
                    commonOrder.setState(1);
                    commonOrderService.updateById(commonOrder);
                }

                if(commonOrder.getShopState()==1){
                    commonOrder.setState(1);
                    commonOrderService.updateById(commonOrder);
                }
                //查询购买订单的用户信息
                HanHaiMember hanHaiMember = hanHaiMemberService.getById(commonOrder.getUserId());
                boolean flag = false;
                //如果这个订单是普通订单
                if (commonOrder.getShopState()==2){
                    //获得这个订单的总价
                    BigDecimal price = commonOrder.getPrice();


                    //根据配置查询比例
                    CommonConfig config = commonConfigService.lambdaQuery()
                            .eq(CommonConfig::getKeyName,"vip_money")
                            .one();

                    //如果总价超过1000元则修改用户为会员
                    if (price.compareTo(new BigDecimal(config.getKeyContent())) > -1){

                        //查看这个用户是否有邀请者，如果有则进入返点
                        //邀请者不能是会员
                        if (hanHaiMember.getIsPay()==0){
                            if (StringUtils.isNotBlank(hanHaiMember.getShareId())){
                                //查询邀请者信息 //修改订单状态在方法内
                                flag = this.getMoneyToUser(commonOrder.getId(), flag);
                            }
                        }

                        //设置成为会员
                        hanHaiMember.setIsPay(1);
                    }
                    //推荐奖励
                    this.toUserPrice(commonOrder.getId(),flag);
                }


                commonOrder.setState(1);
                commonOrderService.updateById(commonOrder);


                hanHaiMemberService.updateById(hanHaiMember);
            }

        }

        return null;
    }

    //加入购物车
    @Override
    public Result<?> addCart(String token,String shopId,Integer num){
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);
        //根据商品标识查询商品信息
        CommonShop commonShop = commonShopService.getById(shopId);
        if (commonShop==null){
            return Result.error("商品不存在");
        }
        //根据商品标识查询购物车是否存在该商品
        CommonCat commonCart = commonCatService.lambdaQuery()
                .eq(CommonCat::getUserId,hanHaiMember.getId())
                .eq(CommonCat::getShopId,shopId)
                .one();
        //如果有则修改数量
        if (commonCart!=null){
            commonCart.setNum(commonCart.getNum()+num);
            commonCatService.updateById(commonCart);
            return Result.OK("修改成功");
        }else{
            CommonCat commonCat = new CommonCat();
            commonCat.setTitle(commonShop.getTitle());
            commonCat.setShopId(commonShop.getId());
            commonCat.setImage(commonShop.getImage());
            commonCat.setSku(commonShop.getSku());
            commonCat.setPrice(commonShop.getPrice());
            commonCat.setUserId(hanHaiMember.getId());
            commonCat.setNum(num);
            commonCat.setCreateTime(new Date());
            commonCatService.save(commonCat);
            return Result.OK("加入成功");
        }
    }

    //删除购物车信息
    @Override
    public Result<?> deleteCart(String token,String ids){
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);
        //删除多个购物车数据
        String[] split = ids.split(",");
        //如果没有,则直接删除
        if (split.length==1){
            commonCatService.removeById(split[0]);
            return Result.OK("删除成功");
        }
        //如果有则循环删除
        for (String id : split) {
            commonCatService.removeById(id);
        }
        return Result.OK("删除成功");
    }


    //修改购物车信息数量
    @Override
    public Result<?> updateCartNum(String token,String id,Integer num){
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);
        CommonCat commonCat = commonCatService.getById(id);
        commonCat.setNum(num);
        commonCatService.updateById(commonCat);
        return Result.OK("修改成功");
    }



    //获取流水记录带分页
    @Override
    public Result<?> getWaterPageList(String token,PageBean pageBean){
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);
        Page<CommonMoneyLog> page = commonMoneyLogService.lambdaQuery()
                .orderByDesc(CommonMoneyLog::getCreateTime)
                .page(new Page<>(1, 10));
        return Result.OK(page);
    }

    //获取订单列表带分页
    @Override
    public Result<?> getOrderPageList(String token, PageBean bean,Integer state){
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);
        Page<CommonOrder> page = new Page<CommonOrder>(bean.getPageNo(), bean.getPageSize());
        Page<CommonOrder> page1 = commonOrderService.lambdaQuery()
                .eq(CommonOrder::getUserId,hanHaiMember.getId())
                .orderByDesc(CommonOrder::getCreateTime)
                .page(page);
        //如果订单状态不为空
        if(null!=state){
            page1 = commonOrderService.lambdaQuery()
                    .eq(CommonOrder::getUserId,hanHaiMember.getId())
                    .eq(CommonOrder::getState,state)
                    .orderByDesc(CommonOrder::getCreateTime)
                    .page(page);
        }
        //拿出订单集合
        List<CommonOrder> records = page1.getRecords();
        //创建新集合
        List<CommonOrder> newRecords = new ArrayList<>();
        for (CommonOrder cityOrder : records) {
            //根据订单id查询订单详情
            List<CommonOrderSku> commonOrderSkuList = commonOrderSkuService.lambdaQuery()
                    .eq(CommonOrderSku::getOrderId,cityOrder.getId())
                    .list();
            cityOrder.setCommonOrderSkuList(commonOrderSkuList);
            newRecords.add(cityOrder);
        }
        page1.setRecords(newRecords);
        return Result.OK(page1);
    }


    //获取订单详情
    @Override
    public Result<?> getOrderDetail(@RequestHeader("X-Access-Token") String token, String id){
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);
        CommonOrder cityOrder = commonOrderService.getById(id);
        //根据订单id查询订单详情
        List<CommonOrderSku> commonOrderSkuList = commonOrderSkuService.lambdaQuery()
                .eq(CommonOrderSku::getOrderId,cityOrder.getId())
                .list();
        cityOrder.setCommonOrderSkuList(commonOrderSkuList);
        return Result.OK(cityOrder);
    }







    //获取粉丝列表带分页
    @Override
    public  Result<?> getFansPageList(String token,PageBean pageBean,String title){
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);
        Page<HanHaiMember> page = hanHaiMemberService
                .lambdaQuery()
                .eq(HanHaiMember::getShareId,hanHaiMember.getId())
                .like(null!=title,HanHaiMember::getNickName,title)
                .page(new Page<>(pageBean.getPageNo(), pageBean.getPageSize()));
        return Result.OK(page);
    }

    //获取购物车信息列表带分页
    @Override
    public Result<?> getCartPageList(String token,PageBean pageBean){
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);
        Page<CommonCat> page = commonCatService
                .lambdaQuery()
                .eq(CommonCat::getUserId,hanHaiMember.getId())
                .page(new Page<>(1, 10));
        return Result.OK(page);
    }

    //获取地址列表带分页
    @Override
    public Result<?> getAddressPageList(String token,PageBean pageBean){
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);
        Page<CommonAddress> page = commonAddressService
                .lambdaQuery()
                .eq(CommonAddress::getUserId,hanHaiMember.getId())
                .page(new Page<>(1, 10));
        return Result.OK(page);
    }



    private String appid = "wx0839bc52e7849c13";

    private String secret = "c614fd865951c5246e849501204e6f7f";

    private String endpoint = "oss-cn-shenzhen.aliyuncs.com";

    private String accessKey = "LTAI5tQSs47izVy8DLVdwUU9";

    private String secretKey = "qHI7C3PaXYZySr84HTToviC71AYlFq";

    private String bucketName = "hanhaiimage";






    private static final String APP_ID = "wx0839bc52e7849c13";
    private static final String APP_SECRET = "c614fd865951c5246e849501204e6f7f";
    private static final String TOKEN_URL = "https://api.weixin.qq.com/cgi-bin/token?grant_type=client_credential&appid=" + APP_ID + "&secret=" + APP_SECRET;
    private static final String TEMPLATE_MESSAGE_URL = "https://api.weixin.qq.com/cgi-bin/message/template/send?access_token=";



    //获取推广二维码
    @Override
    public Result<?> getInviteCode(String token){
        HanHaiMember member = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);

        CommonConfig vsion = commonConfigService.lambdaQuery()
                .eq(CommonConfig::getKeyName, "v_sion")
                .one();
        Integer vsionStr = Integer.parseInt(vsion.getKeyContent());
        String trial = "release";
        if(vsionStr == 0){
            trial= "release";
        }else if(vsionStr == 1){
            trial= "trial";
        }else{
            trial= "develop";
        }

//        WxQrCodeVo o = (WxQrCodeVo)redisUtil.get("CodeImage::" + trial+ member.getId());
//        if(o!=null){
//
//
//            o.setName("瑶都万能墙欢迎您的加入");
//            return Result.OK(o);
//        }

        Map<String, Object> param = new HashMap<>();

        CommonConfig xcxSharePage = commonConfigService.lambdaQuery()
                .eq(CommonConfig::getKeyName, "xcxSharePage")
                .one();





        String key = "shareId=" + member.getId();

        param.put("path", xcxSharePage.getKeyContent() + "?" + key); //跳转页面
        String accessToken = this.getAccessToken();
        RestTemplate rest = new RestTemplate();
        InputStream inputStream = null;
        OutputStream outputStream = null;
        File file = null;

//        LambdaQueryWrapper<DbConf> configImg = new LambdaQueryWrapper<>();
//        configImg.eq(DbConf::getIsDel,0).eq(DbConf::getKeyValue,"codeImg");
//        DbConf oneImg = confService.getOne(configImg);

        CommonConfig oneImage = commonConfigService.lambdaQuery()
                .eq(CommonConfig::getKeyName, "codeImg")
                .one();




        String codeImg = oneImage.getKeyContent();
        try{
            String url = "https://api.weixin.qq.com/wxa/getwxacode?access_token=" + accessToken;
            param.put("scene", member.getId());
            param.put("width", 150);
            param.put("auto_color", false);
            param.put("env_version", trial);
            Map<String, Object> line_color = new HashMap<>();
            line_color.put("r", 0);
            line_color.put("g", 0);
            line_color.put("b", 0);
            param.put("line_color", line_color);
            MultiValueMap<String, String> headers = new LinkedMultiValueMap<>();
            org.springframework.http.HttpEntity requestEntity = new org.springframework.http.HttpEntity(JSON.toJSONString(param), headers);
            ResponseEntity<byte[]> entity = rest.exchange(url, HttpMethod.POST, requestEntity, byte[].class, new Object[0]);
            byte[] result = entity.getBody();

            inputStream = new ByteArrayInputStream(result);
            String tempSave = codeImg;
            String filePath = tempSave;

            file = new File(filePath);
            if (!file.exists()) {
                file.createNewFile();
            }
            outputStream = new FileOutputStream(file);
            int len = 0;
            byte[] buf = new byte[1024];
            while ((len = inputStream.read(buf, 0, 1024)) != -1) {
                outputStream.write(buf, 0, len);
            }
            outputStream.flush();
            /**
             * 将文件上传至阿里云
             */
            DiskFileItemFactory factory = new DiskFileItemFactory(16, null);
            FileItem item = factory.createItem("File", "text/plain", true, file.getName());
            int bytesRead = 0;
            byte[] buffer = new byte[8192];
            try {
                FileInputStream fis = new FileInputStream(file);
                OutputStream os = item.getOutputStream();
                while ((bytesRead = fis.read(buffer, 0, 8192)) != -1) {
                    os.write(buffer, 0, bytesRead);
                }
                os.close();
                fis.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
            MultipartFile mf = new CommonsMultipartFile(item);
            //返回图片下载地址
            WxQrCodeVo wxCodeVo = new WxQrCodeVo();
            wxCodeVo.setUrl(this.uploadAliYunOss(mf));




            wxCodeVo.setName("陌美人珠宝欢迎您");

//            redisUtil.set("CodeImage::"+trial+member.getId(),wxCodeVo);
            return Result.OK(wxCodeVo);

        } catch (Exception e) {
            e.printStackTrace();
        } finally {

            if (inputStream != null) {
                try {
                    inputStream.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
            if (outputStream != null) {
                try {
                    outputStream.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
            //删除文件
            if (file.exists()) {
                file.delete();
            }
        }
        return null;
    }

    @Override
    public Result<?> getInfoIntroduce(String type) {
        return null;
    }


    /**
     * 获取令牌
     *
     * @return
     */
    private String getAccessToken() {
        String requestUrl = "https://api.weixin.qq.com/cgi-bin/token?grant_type=client_credential&appid=" + appid + "&secret=" + secret;
        String doGet2 = HttpClientUtil.doGet2(requestUrl);
        Map<String, String> map = JSON.parseObject(doGet2, new TypeReference<Map<String, String>>() {
        });
        return map.get("access_token");
    }
    /**
     * 上传文件至阿里云oss
     *
     * @return
     */
    private String uploadAliYunOss(MultipartFile mf) throws Exception {
        String uploadFile = "WxCodeFile";
        String fileName = new StringBuffer(mf.getOriginalFilename()).append(".jpg").toString();// 获取文件名
        String dbpath = uploadFile + File.separator + fileName;
        if (dbpath.contains("\\")) {
            dbpath = dbpath.replace("\\", "/");
        }
        String endpoint = this.endpoint;
        String accessKey = this.accessKey;
        String secretKey = this.secretKey;
        // 创建OSSClient实例。
        OSS ossClient = new OSSClientBuilder().build(endpoint, accessKey, secretKey);
        // 上传Byte数组。
        byte[] content = mf.getBytes();
        String bucketName = this.bucketName;
        ossClient.putObject(bucketName, dbpath, new ByteArrayInputStream(content));
        // 关闭OSSClient。
        ossClient.shutdown();
        return dbpath;
    }











    //查询分类接口
    @Override
    public Result<?> getCategoryList(){
        List<CommonClass> list = commonClassService.list();
        return Result.OK(list);
    }


    //增加或者修改地址
    @Override
    public Result<?> addOrUpdateAddress(String token,CommonAddress commonAddress){
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);
        commonAddress.setUserId(hanHaiMember.getId());
        commonAddressService.saveOrUpdate(commonAddress);
        return Result.OK("增加成功");
    }


    //删除地址
    @Override
    public Result<?> deleteAddress(String token,String id){
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);
        commonAddressService.removeById(id);
        return Result.OK("删除成功");
    }

    //修改默认地址
    @Override
    public Result<?> updateDefaultAddress(String token,String id){
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);
        //查询是否有默认地址
        List<CommonAddress> list = commonAddressService.lambdaQuery()
                .eq(CommonAddress::getDefaultFlag,1)
                .list();
        //如果有全部改为不默认
        if (list!=null && list.size()>0){
            for (CommonAddress commonAddress : list) {
                commonAddress.setDefaultFlag(0);
                commonAddressService.updateById(commonAddress);
            }
        }
        //查询当前这个地址信息
        CommonAddress commonAddress = commonAddressService.getById(id);
        commonAddress.setDefaultFlag(1);
        commonAddressService.updateById(commonAddress);

        return Result.OK("修改成功");
    }

    //查询个人信息相关
    @Override
    public Result<?> getRiceInfo(String token){
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);
        Map map = new HashMap();
        //余额、可提现、收益明细
        map.put("balance",hanHaiMember.getPrice());
        map.put("canWithdraw",hanHaiMember.getMoney());
        map.put("income",0);
        //黄金会员
        map.put("goldenMember",0);
        //当前会员人数
        map.put("memberNum",hanHaiMemberService.lambdaQuery().eq(HanHaiMember::getIsPay,1).list().size());
        return Result.OK(map);
    }



    //充值
    @Override
    public Result<?> recharge(String token,BigDecimal money){
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);
        //查询当前用户余额
        CommonMoney commonMoney = commonMoneyService.lambdaQuery()
                .eq(CommonMoney::getUserId,hanHaiMember.getId())
                .one();

        return Result.OK("充值成功");
    }

    //提现
    @Override
    public Result<?> withdraw(String token,BigDecimal money,String bankName,String bankNo){
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);
        //查询当前用户余额
        BigDecimal userPrice = hanHaiMember.getMoney();
        //提现金额不能大于用户额度
        if (userPrice.compareTo(money) == -1){
            //余额不足
            return Result.error("余额不足");
        }
        //创建支付流水
        CommonMoneyLog commonMoneyLog = new CommonMoneyLog();
        commonMoneyLog.setTitle("用户提现");
        commonMoneyLog.setMoney(money);
        commonMoneyLog.setOldMoney(userPrice);
        commonMoneyLog.setType(1);
        commonMoneyLog.setState(0);
//        commonMoneyLog.setBankName(bankName);
//        commonMoneyLog.setBankNo(bankNo);
        commonMoneyLog.setUserId(hanHaiMember.getId());
        commonMoneyLogService.save(commonMoneyLog);

        hanHaiMember.setMoney(userPrice.subtract(money));
        hanHaiMemberService.updateById(hanHaiMember);
        return Result.OK("提现申请成功,等待审核!");
    }







    //这里执行的方法是：会员推荐用户购买会员
    //会员推荐朋友购买会员第一个返10%、第二个返20%、第三个返30%、第四个返40%，四四循环
    public boolean getMoneyToUser(String orderId,boolean flag){
        //根据订单标识查询订单信息
        CommonOrder commonOrder = commonOrderService.getById(orderId);
        if (commonOrder==null){
            log.info("订单不存在：ID:"+orderId);
            return flag;
        }
        //查询是否有推荐购买会员
        HanHaiMember member = hanHaiMemberService.lambdaQuery()
                .eq(HanHaiMember::getId,commonOrder.getUserId())
                .one();
        String orderShareId = member.getShareId();
        if (orderShareId==null || "".equals(orderShareId)){
            log.info("订单没有推荐用户：ID:"+orderId);
            return flag;
        }


        //根据推荐者标识查询推荐者用户信息
        HanHaiMember shareMember = hanHaiMemberService.getById(orderShareId);
        if (shareMember==null){
            log.info("推荐用户不存在：ID:"+orderShareId);
            return flag;
        }
        //推荐用户不是会员也不是渠道
        if (shareMember.getIsPay()==0){
            log.info("推荐用户不是会员也不是渠道：ID:"+orderShareId);
            return flag;
        }
        //根据订单推荐者标识查询该推荐这推荐了几个订单
        List<CommonOrder> list = commonOrderService.lambdaQuery()
                .eq(CommonOrder::getShareId,orderShareId)
                .orderByDesc(CommonOrder::getCreateTime)
                //订单状态1：未付款、2：已付款、3：已发货、4：已收货、5：已完成、 大于0
                .gt(CommonOrder::getState,0)
                .list();
        log.info("订单条数："+list.size());
        //如果为空则跳出
        Integer shareNum = 1;
        if (list==null || list.size()==0){
            shareNum = 1;
        }else{
            //查询有多少个返点配置
            int confSize = commonVipConfigService.list().size();
            if(list.size()+1>confSize){
                //最新的一个订单是第几次循环
                log.info("原订单："+list.get(0).getShareNum());
                shareNum = list.get(0).getShareNum() + 1;
                log.info("现在："+shareNum);
                //根据配置查询vip配置比例
                CommonVipConfig commonVipConfig = commonVipConfigService.lambdaQuery()
                        .eq(CommonVipConfig::getSort,shareNum)
                        .one();
                //如果查出来没有数据
                if (commonVipConfig==null){
                    shareNum = 1;
                }

            }else{
                shareNum = list.size()+1;
                log.info("推荐用户购买会员第几次list.size()+1==："+shareNum);
            }
            log.info("推荐用户购买会员第几次："+shareNum);
        }
        //根据配置查询vip配置比例
        CommonVipConfig commonVipConfig = commonVipConfigService.lambdaQuery()
                .eq(CommonVipConfig::getSort,shareNum)
                .one();
        if (commonVipConfig==null){
            log.info("没有配置该比例：shareNum:"+shareNum);
            return flag;
        }
        //得到比例
        BigDecimal price = commonVipConfig.getPrice();
        //返点金额公式：返点金额 = 当前订单金额乘得到比例
        BigDecimal money = commonOrder.getPrice().multiply(price);

        //判断用户是否是会员
        //增加推荐者流水
        CommonMoneyLog moneyLog = new CommonMoneyLog();
        if(shareMember.getIsPay() == 1){
            if (member.getIsPay()==0){
                moneyLog.setTitle("【会员】直推【普通】第"+shareNum+"次的推荐奖");
                moneyLog.setMoney(money);
                moneyLog.setOldMoney(shareMember.getPrice());
                moneyLog.setType(0); //0收入 1支出
                moneyLog.setState(0);
                moneyLog.setUserId(orderShareId);
                commonMoneyLogService.save(moneyLog);

                flag = true;
            }
        }
        if(shareMember.getIsPay() == 2){

            //根据配置查询比例
            CommonConfig config = commonConfigService.lambdaQuery()
                    .eq(CommonConfig::getKeyName,"qu_price")
                    .one();

            if (member.getIsPay()==0){
                money = new BigDecimal(config.getKeyContent());
                moneyLog.setTitle("渠道推荐用户购买会员");
                moneyLog.setMoney(money);
                moneyLog.setOldMoney(shareMember.getPrice());
                moneyLog.setType(0); //0收入 1支出
                moneyLog.setState(0);
                moneyLog.setUserId(orderShareId);
                commonMoneyLogService.save(moneyLog);
            }
        }
        //修改推荐者的钱
        shareMember.setPrice(shareMember.getPrice().add(money));
        hanHaiMemberService.updateById(shareMember);

        //修改订单的推荐次数
        commonOrder.setState(1);
        commonOrder.setShareId(shareMember.getId());
        commonOrder.setShareNum(shareNum);
        commonOrderService.updateById(commonOrder);

        return flag;
    }



    //    1：用户推荐奖
//    凡购买1盒即5斤享有推荐资格
//    直推奖励：所推荐朋友购买产品或者购买会员返10%佣金，及今后产生复购产品的均有10%佣金（体验价不计算在内）
    public boolean toUserPrice(String orderId,boolean flag){
        CommonOrder commonOrder = commonOrderService.getById(orderId);
        if (commonOrder==null){
            log.info("订单不存在：ID:"+orderId);
            return flag;
        }
        //根据订单查询用户信息
        HanHaiMember hanHaiMember = hanHaiMemberService.lambdaQuery()
                .eq(HanHaiMember::getId,commonOrder.getUserId())
                .one();
        if (hanHaiMember==null){
            log.info("用户不存在：ID:"+commonOrder.getUserId());
            return flag;
        }
        //查询推荐人
        HanHaiMember shareMember = hanHaiMemberService.lambdaQuery()
                .eq(HanHaiMember::getId,hanHaiMember.getShareId())
                .one();
        if (shareMember==null){
            log.info("推荐用户不存在：ID:"+hanHaiMember.getShareId());
            return flag;
        }
        //查询推荐人是否购买了并且支付了订单
        List<CommonOrder> list = commonOrderService.lambdaQuery()
                .eq(CommonOrder::getUserId,shareMember.getId())
                .gt(CommonOrder::getState,0)
                .list();
        if (list==null || list.size()==0){
            log.info("推荐用户没有购买的订单无法进行返点：ID:"+shareMember.getId());
            return flag;
        }

        //增加流水
        CommonMoneyLog moneyLog = new CommonMoneyLog();

        //查看用户是否是会员
        if (shareMember.getIsPay()==0){
            if(hanHaiMember.getIsPay()==0) {
                moneyLog.setTitle("【用户】直推【用户】购买产品奖励");
            }else{
                moneyLog.setTitle("【用户】直推【会员】购买产品奖励");
            }
            //根据配置查询比例
            CommonConfig config = commonConfigService.lambdaQuery()
                    .eq(CommonConfig::getKeyName,"user_price_money")
                    .one();

            moneyLog.setMoney(commonOrder.getPrice().multiply(new BigDecimal(config.getKeyContent())));
            moneyLog.setOldMoney(shareMember.getPrice());
            moneyLog.setType(0);
            moneyLog.setState(0);
            moneyLog.setUserId(shareMember.getId());

            //修改推荐者的钱
            shareMember.setPrice(shareMember.getPrice().add(commonOrder.getPrice().multiply(new BigDecimal(config.getKeyContent()))));
            commonMoneyLogService.save(moneyLog);
        }else if (shareMember.getIsPay()==1){


            //根据配置查询比例
            CommonConfig config = commonConfigService.lambdaQuery()
                    .eq(CommonConfig::getKeyName,"vip_price_money")
                    .one();

            if(hanHaiMember.getIsPay()==1){
                moneyLog.setTitle("【会员】直推【会员】产品购买奖励");
                moneyLog.setMoney(commonOrder.getPrice().multiply(new BigDecimal(config.getKeyContent())));
                moneyLog.setOldMoney(shareMember.getPrice());
                moneyLog.setType(0);
                moneyLog.setState(0);
                moneyLog.setUserId(shareMember.getId());

                shareMember.getPrice().add(commonOrder.getPrice().multiply(new BigDecimal(config.getKeyContent())));
                commonMoneyLogService.save(moneyLog);

            }else{
                if(flag == false){
                    moneyLog.setTitle("【会员】直推【用户】产品购买奖励");
                    moneyLog.setMoney(commonOrder.getPrice().multiply(new BigDecimal(config.getKeyContent())));
                    moneyLog.setOldMoney(shareMember.getPrice());
                    moneyLog.setType(0);
                    moneyLog.setState(0);
                    moneyLog.setUserId(shareMember.getId());

                    shareMember.getPrice().add(commonOrder.getPrice().multiply(new BigDecimal(config.getKeyContent())));
                    commonMoneyLogService.save(moneyLog);
                }

            }




        }else{

            //根据配置查询比例
            CommonConfig config = commonConfigService.lambdaQuery()
                    .eq(CommonConfig::getKeyName,"qu_price_money")
                    .one();

            if(hanHaiMember.getIsPay()==0) {
                moneyLog.setTitle("【渠道】直推【用户】购买产品奖励");
            }else{
                moneyLog.setTitle("【渠道】直推【会员】购买产品奖励");
            }
            moneyLog.setMoney(commonOrder.getPrice().multiply(new BigDecimal(config.getKeyContent())));
            moneyLog.setOldMoney(shareMember.getPrice());
            moneyLog.setType(0);
            moneyLog.setState(0);
            moneyLog.setUserId(shareMember.getId());

            //修改推荐者的钱
            shareMember.setPrice(shareMember.getPrice().add(commonOrder.getPrice().multiply(new BigDecimal(config.getKeyContent()))));
            commonMoneyLogService.save(moneyLog);
        }


        hanHaiMemberService.updateById(shareMember);

        return flag;
    }



    //确认收货
    @Override
    public Result<?> confirmOrder(String token,String orderId){
        HanHaiMember hanHaiMember = shiroRealm.checkUserTokenIsEffectHanHaiOpenId(token);

        return Result.OK("确认收货");

    }







}
