package org.jeecg.modules.commonShop.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.commonShop.entity.CommonShop;
import org.jeecg.modules.commonShop.service.ICommonShopService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 单商户商品信息表
 * @Author: jeecg-boot
 * @Date:   2024-12-13
 * @Version: V1.0
 */
@Api(tags="单商户商品信息表")
@RestController
@RequestMapping("/commonShop/commonShop")
@Slf4j
public class CommonShopController extends JeecgController<CommonShop, ICommonShopService> {
	@Autowired
	private ICommonShopService commonShopService;
	
	/**
	 * 分页列表查询
	 *
	 * @param commonShop
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "单商户商品信息表-分页列表查询")
	@ApiOperation(value="单商户商品信息表-分页列表查询", notes="单商户商品信息表-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<CommonShop>> queryPageList(CommonShop commonShop,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<CommonShop> queryWrapper = QueryGenerator.initQueryWrapper(commonShop, req.getParameterMap());
		Page<CommonShop> page = new Page<CommonShop>(pageNo, pageSize);
		IPage<CommonShop> pageList = commonShopService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param commonShop
	 * @return
	 */
	@AutoLog(value = "单商户商品信息表-添加")
	@ApiOperation(value="单商户商品信息表-添加", notes="单商户商品信息表-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody CommonShop commonShop) {
		commonShopService.save(commonShop);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param commonShop
	 * @return
	 */
	@AutoLog(value = "单商户商品信息表-编辑")
	@ApiOperation(value="单商户商品信息表-编辑", notes="单商户商品信息表-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody CommonShop commonShop) {
		commonShopService.updateById(commonShop);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "单商户商品信息表-通过id删除")
	@ApiOperation(value="单商户商品信息表-通过id删除", notes="单商户商品信息表-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		commonShopService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "单商户商品信息表-批量删除")
	@ApiOperation(value="单商户商品信息表-批量删除", notes="单商户商品信息表-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.commonShopService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "单商户商品信息表-通过id查询")
	@ApiOperation(value="单商户商品信息表-通过id查询", notes="单商户商品信息表-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<CommonShop> queryById(@RequestParam(name="id",required=true) String id) {
		CommonShop commonShop = commonShopService.getById(id);
		if(commonShop==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(commonShop);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param commonShop
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, CommonShop commonShop) {
        return super.exportXls(request, commonShop, CommonShop.class, "单商户商品信息表");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, CommonShop.class);
    }

}
